@@ -1,8 +1,5 @@
 def thumbnail_maker(cover, output):
 
-    from PIL import Image, ImageEnhance, ImageFilter
-    from math import trunc
-
     # Import
     tb = Image.open(cover)
     cv = Image.open(cover)
@@ -29,9 +26,6 @@ def thumbnail_maker(cover, output):
     
 def video_maker(cover, song, artist, toptext, output):
 
-    from PIL import Image, ImageDraw, ImageFont, ImageEnhance, ImageFilter
-    from math import trunc
-
     x, y = (2500, 2500) # Cover size
     X, Y = (7680, 4320) # Background size
 
